==> apache-seatunnel-incubating-2.3.0-src.tar.gz: apache-seatunnel-incubating-2.3.0-src/seatunnel-connectors-v2/connector-pulsar/src/test/java/org/apache/seatunnel/connectors/seatunnel/pulsar/source/PulsarSourceFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.pulsar.source;

import org.apache.seatunnel.api.configuration.util.OptionRule;
import org.apache.seatunnel.connectors.seatunnel.pulsar.config.PulsarConfigUtil;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class PulsarSourceFactoryTest {

    @Test
    void factoryIdentifier() {
        PulsarSourceFactory pulsarSourceFactory = new PulsarSourceFactory();
        Assertions.assertEquals(PulsarConfigUtil.IDENTIFIER, pulsarSourceFactory.factoryIdentifier());
    }

    @Test
    void optionRule() {
        PulsarSourceFactory pulsarSourceFactory = new PulsarSourceFactory();
        OptionRule optionRule = pulsarSourceFactory.optionRule();
        Assertions.assertNotNull(optionRule);
    }
}

==> apache-seatunnel-incubating-2.3.1-src.tar.gz: apache-seatunnel-incubating-2.3.1-src/seatunnel-connectors-v2/connector-pulsar/src/test/java/org/apache/seatunnel/connectors/seatunnel/pulsar/source/PulsarSourceFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.pulsar.source;

import org.apache.seatunnel.api.configuration.util.OptionRule;
import org.apache.seatunnel.connectors.seatunnel.pulsar.config.PulsarConfigUtil;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class PulsarSourceFactoryTest {

    @Test
    void factoryIdentifier() {
        PulsarSourceFactory pulsarSourceFactory = new PulsarSourceFactory();
        Assertions.assertEquals(
                PulsarConfigUtil.IDENTIFIER, pulsarSourceFactory.factoryIdentifier());
    }

    @Test
    void optionRule() {
        PulsarSourceFactory pulsarSourceFactory = new PulsarSourceFactory();
        OptionRule optionRule = pulsarSourceFactory.optionRule();
        Assertions.assertNotNull(optionRule);
    }
}
